
Overview
--------

``seclea-ai`` is the package to integrate with the Seclea Responsible AI Platform.
In order to make use of the functionality you will need an account with Seclea.

Requirements
------------
-  ``python`` = 3.6+
-  ``pandas`` = 1.1+

Installation
------------

Install using ``pip``:

.. code:: bash

    $ pip install seclea-ai
